@@ -407,19 +407,22 @@ class JIRA(object):
 # Groups
 
     # non-resource
-    def groups(self, query=None, exclude=None):
+    def groups(self, query=None, exclude=None, maxResults=None):
         """
         Return a list of groups matching the specified criteria.
 
         Keyword arguments:
         query -- filter groups by name with this string
         exclude -- filter out groups by name with this string
+        maxResults -- maximum results to return. defaults to system property jira.ajax.autocomplete.limit (20)
         """
         params = {}
         if query is not None:
             params['query'] = query
         if exclude is not None:
             params['exclude'] = exclude
+        if maxResults is not None:
+            params['maxResults'] = maxResults
         return self._get_json('groups/picker', params=params)
 
     def group_members(self, group):
